==> gcc-prebuilt-1.0.1.tgz: package/README.md <==
#gcc-prebuilt

[![npm version][npm-img]][npm-url] 

Latest release: [gcc-6.1.0-linux-gnu-x86_64-prebuilt](https://github.com/mawni/gcc-prebuilt/releases)

`gcc-prebuilt` is the latest [gcc](https://gcc.gnu.org/) (the GNU Compiler Collection) prebuilt for Debian-like (e.g. Ubuntu) gnu/linux distros. It is configured for languages `c,c++,go,fortran,objc,obj-c++`. **The [gcc](https://gcc.gnu.org/)'s source code has not been touched at all**. More precisely, `gcc-prebuilt` is just the ready-to-use latest [gcc](https://gcc.gnu.org/) that is built from the [gcc](https://gcc.gnu.org/)'s official source code (without any changes to the source code), configured with the following options, and is made for x86_64 Debian-like gnu/linux distros.

`gcc-prebuilt` is configured with these options (after installation, you can run `gcc -v` to see this):

`Configured with: ../gcc-6.1.0/configure --with-pkgversion='gcc-6.1.0-linux-gnu-x86_64-prebuilt v1.0.0' --with-bugurl=https://github.com/mawni/gcc-prebuilt/issues --prefix=/usr/local/gcc-6.1.0 --libexecdir=/usr/local/gcc-6.1.0/lib --enable-languages=c,c++,go,fortran,objc,obj-c++ --enable-shared --enable-linker-build-id --enable-threads=posix --enable-nls --enable-gnu-unique-object --disable-browser-plugin --enable-objc-gc --disable-multilib --disable-werror --with-system-zlib --enable-checking=release --build=x86_64-linux-gnu --host=x86_64-linux-gnu --target=x86_64-linux-gnu`.

`gcc-prebuilt` installer asks the user for `--prefix` as the gcc's installation top directory. `gcc-prebuilt` can be installed in one of:
 
 0) `$HOME`

 1) `$HOME/.local`
 
 2) `/usr/local` (require root privileges)

####Install

Please use `npm install -g gcc-prebuilt`. If you encounter with a problem or getting `EACCES` error, read [fixing-npm-permissions](https://docs.npmjs.com/getting-started/fixing-npm-permissions). If still not successful, please report that in [issues](https://github.com/mawni/gcc-prebuilt/issues); It will be responded back as fast as possible.

Enjoy using `gcc-prebuilt`.

[travis-img]: https://img.shields.io/travis/mawni/gcc-prebuilt/master.svg
[travis-url]: https://travis-ci.org/mawni/gcc-prebuilt
[npm-img]: https://img.shields.io/npm/v/gcc-prebuilt.svg?maxAge=2592000
[npm-url]: https://www.npmjs.com/package/gcc-prebuilt

==> gcc-prebuilt-1.0.3.tgz: package/README.md <==
#gcc-prebuilt

[![npm version][npm-img]][npm-url] 

Latest release: [gcc-6.1.0-linux-gnu-x86_64-prebuilt](https://github.com/mawni/gcc-prebuilt/releases)

`gcc-prebuilt` is the latest [gcc](https://gcc.gnu.org/) (the GNU Compiler Collection) prebuilt for Debian-like (e.g. Ubuntu) gnu/linux distros. It is configured for languages `c,c++,go,fortran,objc,obj-c++`. **The [gcc](https://gcc.gnu.org/)'s source code has not been touched at all**. More precisely, `gcc-prebuilt` is just the ready-to-use latest [gcc](https://gcc.gnu.org/) that is built from the [gcc](https://gcc.gnu.org/)'s official source code (without any changes to the source code), configured with the following options, and is made for x86_64 Debian-like gnu/linux distros.

`gcc-prebuilt` is configured with these flags (after installation, you can run `gcc -v` to see this):

`Configured with: --with-pkgversion='gcc-6.1.0-linux-gnu-x86_64-prebuilt' --with-bugurl=https://github.com/mawni/gcc-prebuilt/issues --prefix=/usr/local/gcc-6.1.0 --libexecdir=/usr/local/gcc-6.1.0/lib --enable-languages=c,c++,go,fortran,objc,obj-c++ --enable-shared --enable-linker-build-id --enable-threads=posix --enable-nls --enable-gnu-unique-object --disable-browser-plugin --enable-objc-gc --disable-multilib --disable-werror --with-system-zlib --enable-checking=release --build=x86_64-linux-gnu --host=x86_64-linux-gnu --target=x86_64-linux-gnu`.

`gcc-prebuilt` installer asks the user for `--prefix` as the gcc's installation top directory. `gcc-prebuilt` can be installed in one of:
 
  0) `$HOME`

  1) `$HOME/.local`
 
  2) `/usr/local` (require root privileges)

####Install

Please use `npm install -g gcc-prebuilt`. If you encounter with a problem or getting `EACCES` error, read [fixing-npm-permissions](https://docs.npmjs.com/getting-started/fixing-npm-permissions). If still not successful, please report that in [issues](https://github.com/mawni/gcc-prebuilt/issues); It will be responded back as fast as possible.

Enjoy using `gcc-prebuilt`.

[travis-img]: https://img.shields.io/travis/mawni/gcc-prebuilt/master.svg
[travis-url]: https://travis-ci.org/mawni/gcc-prebuilt
[npm-img]: https://img.shields.io/npm/v/gcc-prebuilt.svg?maxAge=2592000
[npm-url]: https://www.npmjs.com/package/gcc-prebuilt
